import { Resource, ResourceProps } from 'aws-cdk-lib';
import { Cluster, FargateProfile, HelmChart, ServiceAccount } from 'aws-cdk-lib/aws-eks';
import { IConstruct } from 'constructs';
import { IWorkspace } from '../aps';
/**
 * Configures the queue used to write to Amazon Managed Service for Prometheus.
 *
 * @see [Remote write configuration](https://prometheus.io/docs/prometheus/latest/configuration/configuration/#remote_write)
 */
export interface QueueConfiguration {
    /**
     * Number of samples to buffer per shard before we block reading of more
     * samples from the WAL. It is recommended to have enough capacity in each
     * shard to buffer several requests to keep throughput up while processing
     * occasional slow remote requests.
     */
    readonly capacity?: number;
    /**
     * Maximum number of samples per send.
     */
    readonly maxSamplesPerSend?: number;
    /**
     * Maximum number of shards, i.e. amount of concurrency.
     */
    readonly maxShards?: number;
}
/**
 * Optional configurations for the Prometheus resource.
 */
export interface PrometheusOptions {
    /**
     * The Kubernetes namespace where the service should be deployed.
     */
    readonly namespace?: string;
    /**
     * Configures the queue used to write to Amazon Managed Service for
     * Prometheus.
     */
    readonly queueConfiguration?: QueueConfiguration;
    /**
     * Name of the Kubernetes service account that should be created and used by
     * Prometheus.
     */
    readonly serviceAccountName?: string;
}
export interface PrometheusProps extends ResourceProps, PrometheusOptions {
    /**
     * The EKS cluster where Prometheus should be deployed.
     */
    readonly cluster: Cluster;
    /**
     * The Amazon Managed Service for Prometheus workspace where the Prometheus
     * server should sned its data.
     */
    readonly workspace: IWorkspace;
}
/**
 * Deploys Prometheus into EKS.
 *
 * The service is run in Fargate and writes data to Amazon Managed Service for
 * Prometheus which provides the backing data store.
 *
 * @see [Official Helm chart documentation](https://github.com/prometheus-community/helm-charts/tree/main/charts/prometheus#readme)
 */
export declare class Prometheus extends Resource {
    /**
     * The name of the Prometheus Helm chart.
     */
    static readonly CHART_NAME: string;
    /**
     * The Helm repository providing the chart to be used for installing the
     * Prometheus service.
     */
    static readonly CHART_REPOSITORY: string;
    /**
     * The default Kubernetes namespace where Prometheus will be installed if an
     * alternative isn't given as input.
     */
    static readonly DEFAULT_NAMESPACE: string;
    /**
     * The EKS cluster where Prometheus should be deployed.
     *
     * @group Inputs
     */
    readonly cluster: Cluster;
    /**
     * The Kubernetes namespace where the service should be deployed.
     *
     * @group Inputs
     */
    readonly namespace: string;
    /**
     * Configures the queue used to write to Amazon Managed Service for
     * Prometheus.
     *
     * @group Inputs
     */
    readonly queueConfiguration?: QueueConfiguration;
    /**
     * Name of the Kubernetes service account that should be created and used by
     * Prometheus.
     *
     * @group Inputs
     */
    readonly serviceAccountName: string;
    /**
     * The Amazon Managed Service for Prometheus workspace where the Prometheus
     * server should sned its data.
     *
     * @group Inputs
     */
    readonly workspace: IWorkspace;
    /**
     * The Helm chart that was used to deploy Prometheus.
     *
     * @group Resources
     */
    readonly chart: HelmChart;
    /**
     * The Fargate profile used for running the service in Fargate.
     */
    readonly fargateProfile: FargateProfile;
    /**
     * The service account that Prometheus will use to gain permissions for
     * Kubernetes and AWS.
     *
     * @group Resources
     */
    readonly serviceAccount: ServiceAccount;
    /**
     * Creates a new instance of the Prometheus class.
     *
     * @param scope A CDK Construct that will serve as this resource's parent
     * in the construct tree.
     * @param id A name to be associated with the resource and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: IConstruct, id: string, props: PrometheusProps);
}
